class BaseColumnCheck():
    ##################################################################################################
    # Constructor
    ##################################################################################################
    def __init__(self, column_name):
        self.column_name = column_name

    ##################################################################################################
    # Properties
    ##################################################################################################
    column_name = None

